<template>
  <!-- 安全隐患排查计划添加 -->
  <div>
    <el-dialog
      :close-on-click-modal="false"
      :title="title + '安全排查计划'"
      :visible.sync="showFormDia"
      width="76%"
      :before-close="handleClose"
      top="8vh"
    >
      <el-form ref="formInfo" :rules="rules" :model="params" label-width="120px">
        <p id="step1" class="from-title">
          <i class="el-icon-info" />
          <span>基础信息</span>
        </p>
        <el-row>
          <el-col :span="6">
            <el-form-item label="排查时间" prop="checkDate">
              <el-date-picker
                v-model="params.checkDate"
                type="date"
                value-format="yyyy-MM-dd"
                placeholder="请选择排查时间"
                style="width:100%;"
                @change="checkYearMonthChange"
              />
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="排查名称" prop="checkName">
              <el-input maxlength="100" show-word-limit v-model="params.checkName" placeholder="请输入排查名称" />
            </el-form-item>
          </el-col>
          <el-col :span="6">
            <el-form-item label="排查方式" prop="checkType">
              <el-select v-model="params.checkType" size="small" style="width:100%;" clearable>
                <el-option
                  v-for="item in pcfsList"
                  :key="item.value"
                  :label="item.name"
                  placeholder="请选择排查方式"
                  :value="item.value"
                />
              </el-select>
            </el-form-item>
          </el-col>
          <!-- <el-col :span="6">
            <el-form-item label="开始时间" prop="checkStartDate">
              <el-date-picker
                v-model="params.checkStartDate"
                size="small"
                type="date"
                value-format="yyyy-MM-dd"
                placeholder="请选择开始时间"
                style="width:100%;"
              />
            </el-form-item>
          </el-col> -->
        </el-row>
        <!-- <el-row>
          <el-col :span="6">
            <el-form-item label="结束时间" prop="checkEndDate">
              <el-date-picker
                v-model="params.checkEndDate"
                size="small"
                type="date"
                value-format="yyyy-MM-dd"
                placeholder="请选择开始时间"
                style="width:100%;"
              />
            </el-form-item>
          </el-col>
        </el-row> -->
        <el-row>
          <el-col :span="24">
            <el-form-item label="排查内容" prop="checkContent">
              <el-input
                show-word-limit
                maxlength="100"
                v-model="params.checkContent"
                :rows="2"
                size="small"
                type="textarea"
                placeholder="请输入排查内容"
                style="width:100%;"
              />
            </el-form-item>
          </el-col>
        </el-row>

        <p id="step1" class="from-title">
          <i class="el-icon-info" />
          <span>排查计划明细</span>
        </p>
      </el-form>
      <div class="table-container">

        <el-table
          ref="singleTable"
          :data="params.detail"
          :style="{width: '100%'}"
          height="300px"
          highlight-current-row
          :cell-style="{'text-align': 'center'}"
          :header-cell-style="{'text-align': 'center'}"
        >
          <el-table-column type="index" width="55" label="序号" />
          <el-table-column label="排查时间" min-width="50" prop="checkDate"></el-table-column>
          <el-table-column label="排查单位" min-width="50" prop="checkCompany">
            <template slot-scope="scope">
              <div>{{ dictTranslation(unitData, scope.row.checkCompany, 'id', 'unitName') }}</div>
            </template>
          </el-table-column>
          <el-table-column label="单位类别" min-width="50" prop="type">
            <template slot-scope="scope">
              <div>{{ dictTranslation(dwlxList, scope.row.type, 'value', 'name') }}</div>
            </template>
          </el-table-column>
          <el-table-column align="right" width="90px" :index="999">
            <template slot="header">
              <el-button size="mini" type="warning" circle icon="el-icon-plus" @click="addTable" />
            </template>
            <template slot-scope="scope">
              <el-button
                size="mini"
                type="danger"
                circle
                icon="el-icon-close"
                @click="delTable(scope.$index, scope.row)"
              />
            </template>
          </el-table-column>
        </el-table>
      </div>
      <span slot="footer" class="dialog-footer">
        <el-button type="primary" @click="handleSave">保 存</el-button>
        <el-button @click="handleClose">取 消</el-button>
      </span>
      <!-- 排查计划明细弹层 -->
      <CmgtSaftyDangerCheckplanFormDialogTroubleshooting
        @addDetail="addDetail"
        ref="troubleshooting"
        :title="'计划'"
      />
    </el-dialog>
  </div>
</template>
<script>
import CmgtSaftyDangerCheckplanApi from '@/views/Manage/saftyDanger/api/CmgtSaftyDangerCheckplanApi'
import dictContracts from '@/components/dict/DictSelectUtils.js'
import moment from 'moment'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import nineLittlePlaceApi from '@/views/Manage/saftyDanger/api/nineLittlePlaceApi'
import CmgtSaftyDangerCheckplanFormDialogTroubleshooting from './CmgtSaftyDangerCheckplanFormDialogTroubleshooting.vue'

export default {
  name: 'CmgtSaftyDangerCheckplanFormDialog',
  components: {CmgtSaftyDangerCheckplanFormDialogTroubleshooting},
  props: {},
  data() {
    return {
      title: '新增',
      showFormDia: false,
      activeCollapseNames: ['1'],
      params: {
        checkDate: null,
        checkType: null,
        checkStartDate: null,
        checkEndDate: null,
        checkContent: null,
        checkName: null,
        deleteDetailsId: [],
        detail: []
      },
      rules: {
        checkName: [
          {
            required: true,
            message: '排查名称不能为空',
            trigger: 'blur'
          }
        ],
        checkDate: [
          {
            required: true,
            message: '排查月度不能为空',
            trigger: 'blur'
          }
        ],
        checkType: [
          {
            required: true,
            message: '排查方式不能为空',
            trigger: 'blur'
          }
        ],
        checkStartDate: [
          {
            required: true,
            message: '开始时间不能为空',
            trigger: 'blur'
          }
        ],
        checkEndDate: [
          {
            required: true,
            message: '结束时间不能为空',
            trigger: 'blur'
          }
        ],
        checkContent: [
          {
            required: true,
            message: '排查内容不能为空',
            trigger: 'blur'
          }
        ]
      },
      units: [],
      unitData: [],
      dwlxList: []
    }
  },
  created() {
    this.pcfsList = dictContracts.getDictItemsFromCache('pclb')
    this.dwlxList = dictContracts.getDictItemsFromCache('zhgl-dwlx')

    // CmgtSaftyDangerCheckplanApi.loadAllUnit(res => {
    // 	this.units = res
    // })
  },
  methods: {
    checkCompanyInput(index, val) {
      this.unitData.forEach(item => {
        if (val == item.id) {
          //   console.log(item)
          this.params.detail[index].type = item.type
        }
      })
    },
    // 字典转义
    dictTranslation(dictList, value, dictValue, dictLabel) {
      for (var i = 0; i < dictList.length; i++) {
        if (dictList[i][dictValue] === value) {
          return dictList[i][dictLabel]
        }
      }
    },
    add() {
      this.showFormDia = true
      this.getUnit()
    },
    handleClose() {
      this.params = {
        checkDate: null,
        checkType: null,
        checkStartDate: null,
        checkName: null,
        checkEndDate: null,
        checkContent: null,
        deleteDetailsId: [],
        detail: []
      }

      this.title = '新增'
      this.showFormDia = false
      this.$refs.formInfo?.resetFields()
    },
    //获取单位
    getUnit() {
      nineLittlePlaceApi.loadCmgtSaftyDangerUnit(
        {
          pageBean: {
            pageSize: -1,
            page: 1
          }
        }
      ).then(res => {
        this.total = res.data.total
        this.unitData = res.data.rows
      })
    },
    handleSave() {
      this.$refs.formInfo.validate(valid => {
        if (valid) {
          let method
          if (!this.params.id) {
            // 新增
            method =
              CmgtSaftyDangerCheckplanApi.addCmgtSaftyDangerCheckplan
          }
          if (this.params.id) {
            // 修改
            method =
              CmgtSaftyDangerCheckplanApi.editCmgtSaftyDangerCheckplan
          }
          method(this.params, res => {
            if (res.state) {
              this.$notify({
                type: 'success',
                message: this.title + '成功',
                duration: 2000
              })
              // this.$emit('loadData')
              this.$parent.loadData()
              this.handleClose()
            } else {
              this.$message.warning(response.message)
            }
          })
        }
      })
    },
    addTable() {
      this.$refs.troubleshooting.add()
      // this.$refs.singleTable.setCurrentRow(this.tableData[this.tableData.length - 1])
    },
    addDetail(list) {
      let arrList = []
      list.forEach(item => {
        // 前端去重
        let boolenVal = this.params.detail.every(it => {
          return item.checkCompany !== it.checkCompany
        })
        if (boolenVal) {
          arrList.push(item)
        }
      })
      this.params.detail = [...this.params.detail, ...arrList].map(i => ({
        ...i,
        checkDate: this.params.checkDate || ''
      }))
    },
    delTable(index, row) {
      this.params.detail.splice(index, 1)
      if (row.id) {
        this.params.deleteDetailsId.push(row.id)
      }
    },
    Update(row) {
      this.getUnit()
      this.title = '修改'
      this.showFormDia = true
      CmgtSaftyDangerCheckplanApi.getItemById(row.id, res => {
        this.params = res
        this.params.deleteDetailsId = []
      })
    },

    // 排查月度改变
    checkYearMonthChange(val) {
      this.params.detail = this.params.detail.map(i => ({
        ...i,
        checkDate: val || ''
      }))
    }
  }
}
</script>
<style lang="scss" scoped>
.step-container {
  width: 80%;
  margin: 0 auto 20px;
}

.dialog-footer {
  text-align: center;
}

::v-deep .table-container {
  .el-table__body-wrapper {
    height: 400px;
    overflow-y: auto;
  }
}
</style>
